@@ -2,6 +2,7 @@ import mysql.connector
 import requests
 import hashlib
 from . import api
+import json
 
 def get_credentials(api_key, api_schema, db_schema):
     response = requests.get(f"{api_schema}/api/db_credentials", headers={'key': api_key, 'db':db_schema}).json()
@@ -29,9 +30,25 @@ def get(api_key, api_schema=None, db_schema=None,  buffered=True, dictionary=Fal
     cur = cnx.cursor(buffered=buffered, dictionary=dictionary)
     return cnx, cur
 
+
 def hash(url):
     return hashlib.sha256(url.encode()).hexdigest()
 
+
+def convert_json(records):
+    """
+    checks if column title has '_json' in string and converts to dict
+    make sure that all json columns have _json in title (and only json columns)
+    """
+    if isinstance(records[0], dict):
+        for record in records:
+            for column, value in record.items():
+                if '_json' in column:
+                    record[column] = json.loads(value)
+    return records
+
+
+
 def null2None(records, dictionary=True):
     result = []
     for record in records:
